@@ -1,6 +1,6 @@
-// $Id: gtkmmproc.cc,v 1.53 2000/05/14 18:48:21 kenelson Exp $
+// $Id: gtkmmproc.cc,v 1.59 2001/02/13 22:00:39 murrayc Exp $
 
-#include <cstdio>
+#include <stdio.h>
 #include <iostream>
 #include <string>
 #include <unistd.h>
@@ -759,7 +759,7 @@ OutputChannel::OutputChannel()
 
   if (!(out_=fopen(temp1,"w")))
     { 
-      cerr << "Could not open "<< tmpfile<<" for output. "<< endl;
+      cerr << "Could not open "<< temp1<<" for output. "<< endl;
       exit (-1);
     }
 
@@ -839,7 +839,7 @@ void OutputChannel::process()
 
 extern int yylineno;
 Environment::Environment()
-  : name_("test"),prefix_("gtkmm_"),
+  : name_("test"), header_prefix_("gtkmm"),
     srcdir_("./"), destdir_("./"),
     local_(false),doc_(false),debug_(false),debug_genh_(false),gnome_(false)
 {}
@@ -851,21 +851,24 @@ void Environment::usage()
 {
   cerr << "Usage: gensig2 [options] name srcdir destdir" << endl
        << "    -h" <<endl
-       << "    --help        This usage message." <<endl
+       << "    --help           This usage message." <<endl
        << endl
-       << "    --doc         Produces a header file for documentation." <<endl
+       << "    --doc            Produces a header file for documentation." <<endl
        << endl
-       << "    --debug       Leave intermediate output arround for analysis." <<endl
+       << "    --debug          Leave intermediate output arround for analysis." <<endl
        << endl
-       << "    --debug-genh  Generate line numbers back to gen_h source file." <<endl
+       << "    --debug-genh     Generate line numbers back to gen_h source file." <<endl
        << endl
-       << "    --m4 dir      Specify the directory with m4 files." <<endl
+       << "    --m4 dir         Specify the directory with m4 files." <<endl
        << endl
        << "    -l" <<endl
-       << "    --local       Local widget (not part of gtk--)." <<endl
+       << "    --local          Local widget (not part of gtk--)." <<endl
+       << endl
+       << "    --header-prefix  Override default header #ifndef name." <<endl
        << endl
        << "    -g" <<endl
-       << "    --gnome       Prefix with GNOME instead of GTKMM." <<endl
+       << "    --gnome          Use GNOMEMM header prefix, instead of GTKMM." << endl
+       << "                     See --header_prefix." <<endl
        << endl
        << "Note: This will read srcdir/name.gen_h file and generates destdir/name.cc" <<endl;
   exit(0);
@@ -891,7 +894,12 @@ void Environment::init(int argc,char** argv)
       else if (tmp=="-g"||tmp=="--gnome")    
         {
           gnome_=true;
-          prefix_="gnome_";
+          header_prefix_="gnomemm";
+        }
+      else if (tmp=="--header-prefix")    
+        {
+          i++;
+          header_prefix_ = argv[i];
         }
       else if (tmp=="-h"||tmp=="--help")
         {
@@ -958,7 +966,7 @@ void Environment::print_includes(FILE *fptr)
 
 string Environment::m4_invoke()
 {
-  if (m4_include_=="")
+  if (!m4_include_.length())
     return M4 " -I " MACRO_DIR " ";
   else 
     return M4 " -I " + m4_include_ + " -I " MACRO_DIR " ";
@@ -966,8 +974,17 @@ string Environment::m4_invoke()
 
 string Environment::firewall()
 {
-  if(gnome())
-    return "gnomemm_" + name_;
+  //Command-line --header-prefix arg can override default header #IFDEFs 
+  if(header_prefix_.size())
+  {
+    return header_prefix_ + "_" + name_;
+  }
   else
-    return "gtkmm_" + name_;
+  {
+    //This shouldn't happen (header_prefix_ always has a value):
+	  if(gnome())
+	    return "gnomemm_" + name_;
+	  else
+	    return "gtkmm_" + name_;
+	}
 }
